@@ -16,6 +16,8 @@
 // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
+#![allow(clippy::transmute_ptr_to_ptr)]
+
 pub use self::module::PyModule;
 pub use self::object::PyObject;
 pub use self::typeobject::PyType;
@@ -31,6 +33,7 @@ pub use self::capsule::PyCapsule;
 pub use self::dict::PyDict;
 pub use self::iterator::PyIterator;
 pub use self::list::PyList;
+pub use self::none::PyNone;
 #[cfg(feature = "python27-sys")]
 pub use self::num::PyInt;
 #[cfg(feature = "python3-sys")]
@@ -139,6 +142,7 @@ pub mod exc;
 mod iterator;
 mod list;
 mod module;
+mod none;
 mod num;
 mod object;
 mod sequence;
