@@ -3,7 +3,7 @@
 use cpython::_detail::ffi;
 use cpython::*;
 use std::cell::{Cell, RefCell};
-use std::sync::atomic::{AtomicBool, Ordering};
+use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
 use std::sync::Arc;
 use std::{isize, iter, mem};
 
@@ -28,7 +28,7 @@ macro_rules! py_expect_exception {
         let res = $py.run($code, None, Some(&d));
         let err = res.unwrap_err();
         if !err.matches($py, $py.get_type::<exc::$err>()) {
-            panic!(format!("Expected {} but got {:?}", stringify!($err), err))
+            panic!("Expected {} but got {:?}", stringify!($err), err)
         }
     }};
 }
@@ -189,6 +189,34 @@ fn instance_method() {
     py.run("assert obj.method() == 42", None, Some(&d)).unwrap();
 }
 
+py_class!(class InstanceMethodReturnsNone |py| {
+    data member: AtomicUsize;
+
+    def value(&self) -> PyResult<usize> {
+        Ok(self.member(py).load(Ordering::Relaxed))
+    }
+
+    def incr(&self) -> PyResult<PyNone> {
+        self.member(py).fetch_add(1, Ordering::Relaxed);
+        Ok(PyNone)
+    }
+});
+
+#[test]
+fn instance_method_returns_none() {
+    let gil = Python::acquire_gil();
+    let py = gil.python();
+
+    let obj = InstanceMethodReturnsNone::create_instance(py, AtomicUsize::new(0)).unwrap();
+    assert!(obj.incr(py).unwrap() == PyNone);
+    assert!(obj.value(py).unwrap() == 1);
+    let d = PyDict::new(py);
+    d.set_item(py, "obj", obj).unwrap();
+    py.run("assert obj.value() == 1", None, Some(&d)).unwrap();
+    py.run("assert obj.incr() is None", None, Some(&d)).unwrap();
+    py.run("assert obj.value() == 2", None, Some(&d)).unwrap();
+}
+
 py_class!(class InstanceMethodWithArgs |py| {
     data member: i32;
 
@@ -1276,3 +1304,78 @@ fn properties() {
     py_run!(py, c, "del c.prop_by_opt_ref");
     py_run!(py, c, "repr(c) == 'P(42, \"testing\" \"DELETED\")'");
 }
+
+py_class!(pub(crate) class ClassWithVisibility |py| {
+  pub(crate) def __new__(_cls) -> PyResult<Self> {
+    Self::create_instance(py)
+  }
+
+  @classmethod
+  pub(crate) def class_method(cls) -> PyResult<String> {
+    Ok(format!("{}.class_method()!", cls.name(py)))
+  }
+
+  @staticmethod
+  pub(crate) def static_method() -> PyResult<&'static str> {
+    Ok("ClassWithVisibility.static_method()!")
+  }
+
+  pub(crate) def instance_method(&self) -> PyResult<i32> {
+    Ok(12345)
+  }
+});
+
+#[test]
+fn class_with_visibility() {
+    let gil = Python::acquire_gil();
+    let py = gil.python();
+    let typeobj = py.get_type::<ClassWithVisibility>();
+    assert!(typeobj
+        .call(py, NoArgs, None)
+        .unwrap()
+        .cast_into::<ClassWithVisibility>(py)
+        .is_ok());
+
+    let d = PyDict::new(py);
+    d.set_item(py, "C", py.get_type::<ClassWithVisibility>())
+        .unwrap();
+    py.run(
+        "assert C.class_method() == 'ClassWithVisibility.class_method()!'",
+        None,
+        Some(&d),
+    )
+    .unwrap();
+    py.run(
+        "assert C().class_method() == 'ClassWithVisibility.class_method()!'",
+        None,
+        Some(&d),
+    )
+    .unwrap();
+
+    assert_eq!(
+        ClassWithVisibility::static_method(py).unwrap(),
+        "ClassWithVisibility.static_method()!"
+    );
+    let d = PyDict::new(py);
+    d.set_item(py, "C", py.get_type::<ClassWithVisibility>())
+        .unwrap();
+    py.run(
+        "assert C.static_method() == 'ClassWithVisibility.static_method()!'",
+        None,
+        Some(&d),
+    )
+    .unwrap();
+    py.run(
+        "assert C().static_method() == 'ClassWithVisibility.static_method()!'",
+        None,
+        Some(&d),
+    )
+    .unwrap();
+
+    let obj = ClassWithVisibility::create_instance(py).unwrap();
+    assert!(obj.instance_method(py).unwrap() == 12345);
+    let d = PyDict::new(py);
+    d.set_item(py, "obj", obj).unwrap();
+    py.run("assert obj.instance_method() == 12345", None, Some(&d))
+        .unwrap();
+}
