@@ -1,4 +1,4 @@
-use cpython::{py_fn, NoArgs, ObjectProtocol, PyDict, PyResult, Python};
+use cpython::{py_fn, NoArgs, ObjectProtocol, PyDict, PyNone, PyResult, Python};
 use std::sync::atomic;
 use std::sync::atomic::Ordering::Relaxed;
 
@@ -135,14 +135,14 @@ fn opt_args() {
     });
 
     assert_eq!(
-        obj.call(py, (py.None(), "string"), None)
+        obj.call(py, (PyNone, "string"), None)
             .unwrap()
             .extract::<String>(py)
             .unwrap(),
         r#"a: None  b: "string"  c: None"#,
     );
     assert_eq!(
-        obj.call(py, ("double", "string", py.None()), None)
+        obj.call(py, ("double", "string", PyNone), None)
             .unwrap()
             .extract::<String>(py)
             .unwrap(),
@@ -157,6 +157,30 @@ fn opt_args() {
     );
 }
 
+#[test]
+fn none_return() {
+    static CALL_COUNT: atomic::AtomicUsize = atomic::AtomicUsize::new(0);
+
+    fn f(_py: Python) -> PyResult<PyNone> {
+        CALL_COUNT.fetch_add(1, Relaxed);
+        Ok(PyNone)
+    }
+
+    let gil = Python::acquire_gil();
+    let py = gil.python();
+    let obj = py_fn!(py, f());
+
+    assert_eq!(CALL_COUNT.load(Relaxed), 0);
+    assert_eq!(
+        obj.call(py, NoArgs, None)
+            .unwrap()
+            .extract::<PyNone>(py)
+            .unwrap(),
+        PyNone,
+    );
+    assert_eq!(CALL_COUNT.load(Relaxed), 1);
+}
+
 /* TODO: reimplement flexible sig support
 #[test]
 fn flexible_sig() {
